@@ -4,12 +4,14 @@
 
 __author__ = 'MIT Data To AI Lab'
 __email__ = 'dailabmit@gmail.com'
-__version__ = '0.2.2'
+__version__ = '0.3.0'
 
 from ctgan.demo import load_demo
-from ctgan.synthesizer import CTGANSynthesizer
+from ctgan.synthesizers.ctgan import CTGANSynthesizer
+from ctgan.synthesizers.tvae import TVAESynthesizer
 
 __all__ = (
     'CTGANSynthesizer',
+    'TVAESynthesizer',
     'load_demo'
 )
